# The Jet Cluster
[@IMG University of Vienna](https://jet01.img.univie.ac.at) :rocket:

[[_TOC_]]

# Getting Started

Welcome to the HPC @IMG @UNIVIE and please follow these steps to become a productive member of our department and make good use of the computer resources. 
**Efficiency is keen.**
1. Connect to Jet
2. Load environment (libraries, compilers, interpreter, tools)
3. Checkout Code, Program, Compile, Test
4. Submit to compute Nodes

[How to SSH / VNC / VPN](SSH-VPN-VNC/README.md)

## Jupyterhub
<img src="https://jupyter.org/assets/hublogo.svg" width="300px">

The Jet-cluster serves a [jupyterhub](https://jupyterhub.readthedocs.io/en/stable/) with a [jupyterlab](https://jupyterlab.readthedocs.io/en/stable/) that launches on the jet-cluster compute nodes and allows users to work directly on the cluster as well as submit jobs.

Goto: [](https://jet01.img.univie.ac.at) from within the VPN or UNI-Network.
Login with your jet-Credentials, choose a job and the jupyterlab will be launched.

<img src="Documentation/jet-login.png" width="500px">

<img src="Documentation/jet-job1.png" width="500px">

<img src="Documentation/jet-job2.png" width="500px">

There are several kernels available and some help can be found:
 - [Python/](Python/)
 - [Tutorial on Jet](Python/Your-First-Notebook-onJet_v2.ipynb)

## User Quotas and Restrictions

Memory limit / slurm requests

:construction:

### Network drives
Currently there are two network drives mounted on the jet cluster. These are connected to the [SRVX8](SRVX8.md) and data can be transfered or accessed like this on the jet cluster. Be aware that the data needs to be transfered via the network before and latencies are higher.
```
131.130.157.8:/raid61        400T  378T   22T  95% /raid61
131.130.157.8:/raid60        319T  309T   11T  97% /raid60
jetfs                        1.1P   81T  975T   8% /jetfs
```

# System Information
Last Update: 4.12.2020
Node Setup
 - 2x Login Nodes
 - 7x Compute Nodes

![GPFS](Documentation/GPFS-jet.png)


## Node Information

| Name | Value |
| --- | --- |
| Product | ThinkSystem SR650 |
| Processor | Intel(R) Xeon(R) Gold 6148 CPU @ 2.40GHz |
| Cores | 2 CPU,  20 physical cores per CPU, total 80 logical CPU units |
| CPU Time | 350 kh |
| Memory | 755 GB Total |
| Memory/Core | 18.9 GB |
| Network | 40 Gbit/s (Infiniband) |

Global file system (GPFS) is present on all nodes with about 1 PB (~1000 TB) of storage.

# Software

The typcial installation of a intel-cluster has the INTEL Compiler suite (`intel-parallel-studio`) and the open source GNU Compilers installed. Based on these two different compilers (`intel`, `gnu`), there are usually two version of each scientific software.
Major Libraries:
 - OpenMPI (3.1.6, 4.0.5)
 - HDF5 
 - NetCDF (C, Fortran)
 - ECCODES from [ECMWF](https://confluence.ecmwf.int/display/ECC)
 - Math libraries e.g. intel-mkl, lapack,scalapack
 - Interpreters: Python, Julia
 - Tools: cdo, ncl, nco, ncview

These software libraries are usually handled by environment modules.

![](https://upload.wikimedia.org/wikipedia/en/thumb/0/0a/Environment_Modules_logo.svg/320px-Environment_Modules_logo.svg.png)

## Currently installed modules

```bash
$ module av
------------------------------------ /jetfs/spack/share/spack/modules/linux-rhel8-haswell -------------------------------------
intel-parallel-studio/composer.2017.7-intel-17.0.7-disfj2g  

--------------------------------- /jetfs/spack/share/spack/modules/linux-rhel8-skylake_avx512 ---------------------------------
anaconda2/2019.10-gcc-8.3.1-5pou6ji                         nco/4.9.3-intel-20.0.2-dhlqiyo                     
anaconda3/2019.10-gcc-8.3.1-tmy5mgp                         ncview/2.1.8-gcc-8.3.1-s2owtzw                     
anaconda3/2020.07-gcc-8.3.1-weugqkf                         ncview/2.1.8-intel-20.0.2-3taqdda                  
anaconda3/2020.11-gcc-8.3.1-gramgir                         netcdf-c/4.7.4-gcc-8.3.1-fh4nn6k                   
cdo/1.9.8-gcc-8.3.1-ipgvzeh                                 netcdf-c/4.7.4-gcc-8.3.1-MPI3.1.6-y5gknpt          
eccodes/2.18.0-gcc-8.3.1-s7clum3                            netcdf-c/4.7.4-intel-20.0.2-337uqtc                
eccodes/2.18.0-intel-20.0.2-6tadpgr                         netcdf-fortran/4.5.3-gcc-8.3.1-kfd2vkj             
enstools/2020.11.dev-gcc-8.3.1-fes7kgo                      netcdf-fortran/4.5.3-gcc-8.3.1-MPI3.1.6-rjcxqb6    
esmf/7.1.0r-gcc-8.3.1-4fijz4q                               netcdf-fortran/4.5.3-intel-20.0.2-irdm5gq          
gcc/8.3.1-gcc-8.3.1-pp3wjou                                 netlib-lapack/3.8.0-gcc-8.3.1-ue37lic              
geos/3.8.1-gcc-8.3.1-o76leir                                netlib-scalapack/2.1.0-gcc-8.3.1-pbkjymd           
hdf5/1.10.7-gcc-8.3.1-MPI3.1.6-vm3avor                      openblas/0.3.10-gcc-8.3.1-ncess5c                  
hdf5/1.12.0-gcc-8.3.1-awl4atl                               openmpi/3.1.6-gcc-8.3.1-rk5av53                    
hdf5/1.12.0-intel-20.0.2-ezeotzr                            openmpi/3.1.6-intel-20.0.2-ubasrpk                 
intel-mkl/2020.3.279-gcc-8.3.1-5xeezjw                      openmpi/4.0.5-gcc-8.3.1-773ztsv                    
intel-mkl/2020.3.279-intel-20.0.2-m7bxged                   openmpi/4.0.5-intel-20.0.2-4wfaaz4                 
intel-oneapi-compilers/2021.2.0-oneapi-2021.2.0-6kdzddx     openmpi/4.0.5-oneapi-2021.2.0-hrfsxrd              
intel-oneapi-mpi/2021.2.0-oneapi-2021.2.0-haqpxfl           parallel-netcdf/1.12.1-gcc-8.3.1-MPI3.1.6-gng2jcu  
intel-parallel-studio/composer.2020.2-intel-20.0.2-zuot22y  parallel-netcdf/1.12.1-gcc-8.3.1-xxrhtxn           
julia/1.5.2-gcc-8.3.1-3iwgkf7                               parallel-netcdf/1.12.1-intel-20.0.2-sgz3yqs        
libemos/4.5.9-gcc-8.3.1-h3lqu2n                             perl/5.32.0-intel-20.0.2-2d23x7l                   
miniconda2/4.7.12.1-gcc-8.3.1-zduqggv                       proj/7.1.0-gcc-8.3.1-xcjaco5                       
miniconda3/4.8.2-gcc-8.3.1-3m7b6t2                          zlib/1.2.11-gcc-8.3.1-bbbpnzp                      
ncl/6.6.2-gcc-8.3.1-MPI3.1.6-3dxuv5f                        zlib/1.2.11-intel-20.0.2-3h374ov                   
nco/4.9.3-gcc-8.3.1-g7o6lao 
```
on how to use environment modules go to [Using Environment Modules](Misc/Environment-Modules.md)


## Slurm
[Slurm Tutorial on Gitlab](https://gitlab.phaidra.org/imgw/slurm) 🔒
